# :sunny: :umbrella: :cloud: pyweatherfr

pyweatherfr displays weather forecast for a given town in France


# 🚀 How to use **pyweatherfr**

pyweatherfr \[TOWN\]

example : ``pyweatherfr Grenoble`` to display weather forecast in town Grenoble

## Other options

  - ``-h/--help``    show the help message and exit
  - ``-u/--update``  update pyweatherfr

# ⚙️ Install

See [this page](INSTALL.md)

# :construction_worker: Contribution

See [this page](CONTRIBUTING.md)

# :package: Changelog

See [this page](CHANGELOG.md)


# License

MIT License

Copyright (c) 2021 [thib1984](https://github.com/thib1984)

See [this page](LICENSE.txt) for details
